@@ -1061,7 +1061,10 @@ def _check_mailmap(name, email, git_repo):
         - *str* – corresponding username from mailmap
         - *str* – corresponding email from mailmap
     """
-    test_str = '{} <{}>'.format(name, email)
+    if name.strip().startswith('--'):
+        test_str = '<{}>'.format(email)
+    else:
+        test_str = '{} <{}>'.format(name, email)
     out_str = git.Git(str(git_repo.path)).check_mailmap(test_str)
 
     matches = re.findall("^(.*) <(.*)>$", out_str)
